@@ -4,6 +4,7 @@ from pydantic_openapi_helper.core import get_openapi
 from pydantic_openapi_helper.inheritance import class_mapper
 from honeybee_schema.model import Model
 from honeybee_schema.energy.simulation import SimulationParameter
+from honeybee_schema.validation import ValidationReport
 
 import json
 import argparse
@@ -40,7 +41,8 @@ info = {
 
 modules = [
     {'module': [Model], 'name': 'Model'},
-    {'module': [SimulationParameter], 'name': 'Simulation Parameter'}
+    {'module': [SimulationParameter], 'name': 'Simulation Parameter'},
+    {'module': [ValidationReport], 'name': 'Validation Report'}
 ]
 
 
